Synthetic observations
======================

.. autofunction:: aeolus.synthobs.read_spectral_bands
.. autofunction:: aeolus.synthobs.read_normalized_stellar_flux
.. autofunction:: aeolus.synthobs.calc_stellar_flux
.. autofunction:: aeolus.synthobs.calc_transmission_spectrum_day_night_average
